@@ -70,7 +70,7 @@ class GetCacheMixin:
     def _get(self, url) -> dict:
         if url is None and self._cache is not None:
             return self._cache
-        return super()._get(url)
+        return super()._get(url=url)
 
 
 class CacheMixin(GetCacheMixin, BaseCacheMixin):
@@ -91,12 +91,12 @@ class CacheMixin(GetCacheMixin, BaseCacheMixin):
 
     def _post(self, payload: dict):
         self._payload = payload
-        super()._post(payload)
+        super()._post(payload=payload)
         self._memory_cache = None
         self._flush_cache_related_points()
 
     def _post_file(self, file, file_name, type_):
-        super()._post_file(file, file_name, type_)
+        super()._post_file(file=file, file_name=file_name, type_=type_)
         self._memory_cache = None
         self._flush_cache_related_points()
 
@@ -119,6 +119,6 @@ class CacheObjectMixin(GetCacheMixin, BaseCacheMixin):
 
     def _put(self, payload: dict):
         self._payload = payload
-        super()._put(payload)
+        super()._put(payload=payload)
         self._memory_cache = None
         self._flush_cache_related_points()
