@@ -205,7 +205,7 @@ class ContractPoint(FilterMixin, CacheMixin, Point):
                  timeout: tuple = (30, 30),
                  pagination_pages: int = 1,
                  ):
-        super().__init__(user, query_params, is_async, timeout)
+        super().__init__(user=user, query_params=query_params, is_async=is_async, timeout=timeout)
         self._pagination_pages = pagination_pages
         self.__next_pagination_page = None
 
